/*
 * uni_attribute.c
 *
 * Common Lisp character attribute table.
 * Generated automatically by the gen-ctype utility for Unicode 3.2.0.
 */

static const uintB unicode_attribute_table_page00[256] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0000-0x001f */
  0x55, 0x55, 0x55, 0x55, 0xaa, 0xaa, 0x5a, 0x55, /* 0x0020-0x003f */
  0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x55, /* 0x0040-0x005f */
  0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x15, /* 0x0060-0x007f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0080-0x009f */
  0x55, 0x55, 0x75, 0x55, 0x55, 0x5d, 0x75, 0x55, /* 0x00a0-0x00bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, /* 0x00c0-0x00df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, /* 0x00e0-0x00ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0100-0x011f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0120-0x013f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0140-0x015f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0160-0x017f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0180-0x019f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x01a0-0x01bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x01c0-0x01df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x01e0-0x01ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0200-0x021f */
  0xf3, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, /* 0x0220-0x023f */
  0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, /* 0x0240-0x025f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0260-0x027f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0280-0x029f */
  0xff, 0xff, 0xff, 0x0f, 0xff, 0xff, 0xd7, 0xff, /* 0x02a0-0x02bf */
  0x5f, 0x55, 0x55, 0x55, 0x5f, 0x55, 0x55, 0x55, /* 0x02c0-0x02df */
  0xff, 0x57, 0x55, 0x35, 0x00, 0x00, 0x00, 0x00, /* 0x02e0-0x02ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x0300-0x031f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x0320-0x033f */
  0x55, 0x55, 0x55, 0x55, 0x00, 0x00, 0x00, 0x00, /* 0x0340-0x035f */
  0x55, 0x55, 0x55, 0x55, 0x00, 0x05, 0x30, 0x10, /* 0x0360-0x037f */
  0x00, 0x75, 0x3f, 0xf3, 0xff, 0xff, 0xff, 0xff, /* 0x0380-0x039f */
  0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x03a0-0x03bf */
  0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, /* 0x03c0-0x03df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00  /* 0x03e0-0x03ff */
};

static const uintB unicode_attribute_table_page04[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0400-0x041f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0420-0x043f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0440-0x045f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0460-0x047f */
  0x5f, 0x15, 0xf5, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0480-0x049f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x04a0-0x04bf */
  0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, /* 0x04c0-0x04df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0x0f, 0x00, /* 0x04e0-0x04ff */
  0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, /* 0x0500-0x051f */
  0x00, 0x00, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, /* 0x0520-0x053f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x5c, 0x55, /* 0x0540-0x055f */
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0560-0x057f */
  0xff, 0xff, 0x14, 0x00, 0x54, 0x55, 0x55, 0x55, /* 0x0580-0x059f */
  0x45, 0x55, 0x55, 0x55, 0x55, 0x55, 0x45, 0x55, /* 0x05a0-0x05bf */
  0x55, 0x01, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, /* 0x05c0-0x05df */
  0xff, 0xff, 0x3f, 0x00, 0x7f, 0x01, 0x00, 0x00, /* 0x05e0-0x05ff */
  0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x40, 0x40, /* 0x0600-0x061f */
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x00, /* 0x0620-0x063f */
  0xff, 0xff, 0x7f, 0x55, 0x55, 0x05, 0x00, 0x00, /* 0x0640-0x065f */
  0xaa, 0xaa, 0x5a, 0xf5, 0xfd, 0xff, 0xff, 0xff, /* 0x0660-0x067f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0680-0x069f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x06a0-0x06bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x5d, 0x55, 0x55, /* 0x06c0-0x06df */
  0x55, 0x7d, 0x55, 0x05, 0xaa, 0xaa, 0xfa, 0x17, /* 0x06e0-0x06ff */
  0x55, 0x55, 0x55, 0x45, 0xf7, 0xff, 0xff, 0xff, /* 0x0700-0x071f */
  0xff, 0xff, 0xff, 0x03, 0x55, 0x55, 0x55, 0x55, /* 0x0720-0x073f */
  0x55, 0x55, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0740-0x075f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0760-0x077f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0780-0x079f */
  0xff, 0x5f, 0x55, 0x55, 0x0d, 0x00, 0x00, 0x00, /* 0x07a0-0x07bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x07c0-0x07df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x07e0-0x07ff */
};

static const uintB unicode_attribute_table_page08[256] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0800-0x081f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0820-0x083f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0840-0x085f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0860-0x087f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0880-0x089f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x08a0-0x08bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x08c0-0x08df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x08e0-0x08ff */
  0x54, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0900-0x091f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0x5d, /* 0x0920-0x093f */
  0x55, 0x55, 0x55, 0x05, 0x57, 0x01, 0xff, 0xff, /* 0x0940-0x095f */
  0x5f, 0xa5, 0xaa, 0xaa, 0x01, 0x00, 0x00, 0x00, /* 0x0960-0x097f */
  0x54, 0xfc, 0xff, 0xc3, 0xc3, 0xff, 0xff, 0xff, /* 0x0980-0x099f */
  0xff, 0xff, 0xf3, 0xff, 0x33, 0xf0, 0x0f, 0x51, /* 0x09a0-0x09bf */
  0x55, 0x41, 0x41, 0x05, 0x00, 0x40, 0x00, 0xcf, /* 0x09c0-0x09df */
  0x5f, 0xa0, 0xaa, 0xaa, 0x5f, 0x55, 0x15, 0x00, /* 0x09e0-0x09ff */
  0x10, 0xfc, 0x3f, 0xc0, 0xc3, 0xff, 0xff, 0xff, /* 0x0a00-0x0a1f */
  0xff, 0xff, 0xf3, 0xff, 0xf3, 0x3c, 0x0f, 0x51, /* 0x0a20-0x0a3f */
  0x15, 0x40, 0x41, 0x05, 0x00, 0x00, 0xfc, 0x33, /* 0x0a40-0x0a5f */
  0x00, 0xa0, 0xaa, 0xaa, 0xf5, 0x03, 0x00, 0x00, /* 0x0a60-0x0a7f */
  0x54, 0xfc, 0xff, 0xcc, 0xcf, 0xff, 0xff, 0xff, /* 0x0a80-0x0a9f */
  0xff, 0xff, 0xf3, 0xff, 0xf3, 0xfc, 0x0f, 0x5d, /* 0x0aa0-0x0abf */
  0x55, 0x45, 0x45, 0x05, 0x03, 0x00, 0x00, 0x00, /* 0x0ac0-0x0adf */
  0x03, 0xa0, 0xaa, 0xaa, 0x00, 0x00, 0x00, 0x00, /* 0x0ae0-0x0aff */
  0x54, 0xfc, 0xff, 0xc3, 0xc3, 0xff, 0xff, 0xff, /* 0x0b00-0x0b1f */
  0xff, 0xff, 0xf3, 0xff, 0xf3, 0xf0, 0x0f, 0x5d, /* 0x0b20-0x0b3f */
  0x55, 0x40, 0x41, 0x05, 0x00, 0x50, 0x00, 0xcf, /* 0x0b40-0x0b5f */
  0x0f, 0xa0, 0xaa, 0xaa, 0x01, 0x00, 0x00, 0x00, /* 0x0b60-0x0b7f */
  0xd0, 0xfc, 0x3f, 0xf0, 0xf3, 0x0f, 0x3c, 0xf3, /* 0x0b80-0x0b9f */
  0xc0, 0x03, 0x3f, 0xf0, 0xff, 0xcf, 0x0f, 0x50, /* 0x0ba0-0x0bbf */
  0x15, 0x50, 0x51, 0x05, 0x00, 0x40, 0x00, 0x00, /* 0x0bc0-0x0bdf */
  0x00, 0x80, 0xaa, 0xaa, 0x15, 0x00, 0x00, 0x00  /* 0x0be0-0x0bff */
};

static const uintB unicode_attribute_table_page0c[256] = {
  0x54, 0xfc, 0xff, 0xf3, 0xf3, 0xff, 0xff, 0xff, /* 0x0c00-0x0c1f */
  0xff, 0xff, 0xf3, 0xff, 0xff, 0xfc, 0x0f, 0x50, /* 0x0c20-0x0c3f */
  0x55, 0x51, 0x51, 0x05, 0x00, 0x14, 0x00, 0x00, /* 0x0c40-0x0c5f */
  0x0f, 0xa0, 0xaa, 0xaa, 0x00, 0x00, 0x00, 0x00, /* 0x0c60-0x0c7f */
  0x50, 0xfc, 0xff, 0xf3, 0xf3, 0xff, 0xff, 0xff, /* 0x0c80-0x0c9f */
  0xff, 0xff, 0xf3, 0xff, 0xff, 0xfc, 0x0f, 0x50, /* 0x0ca0-0x0cbf */
  0x55, 0x51, 0x51, 0x05, 0x00, 0x14, 0x00, 0x30, /* 0x0cc0-0x0cdf */
  0x0f, 0xa0, 0xaa, 0xaa, 0x00, 0x00, 0x00, 0x00, /* 0x0ce0-0x0cff */
  0x50, 0xfc, 0xff, 0xf3, 0xf3, 0xff, 0xff, 0xff, /* 0x0d00-0x0d1f */
  0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0x0f, 0x50, /* 0x0d20-0x0d3f */
  0x55, 0x50, 0x51, 0x05, 0x00, 0x40, 0x00, 0x00, /* 0x0d40-0x0d5f */
  0x0f, 0xa0, 0xaa, 0xaa, 0x00, 0x00, 0x00, 0x00, /* 0x0d60-0x0d7f */
  0x50, 0xfc, 0xff, 0xff, 0xff, 0x3f, 0xf0, 0xff, /* 0x0d80-0x0d9f */
  0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xff, 0x0c, /* 0x0da0-0x0dbf */
  0xff, 0x3f, 0x10, 0x40, 0x55, 0x11, 0x55, 0x55, /* 0x0dc0-0x0ddf */
  0x00, 0x00, 0x00, 0x00, 0x50, 0x01, 0x00, 0x00, /* 0x0de0-0x0dff */
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0e00-0x0e1f */
  0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x3f, 0x40, /* 0x0e20-0x0e3f */
  0xff, 0xdf, 0xff, 0x7f, 0xaa, 0xaa, 0x5a, 0x00, /* 0x0e40-0x0e5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0e60-0x0e7f */
  0x3c, 0xc3, 0x33, 0x0c, 0x00, 0xff, 0xfc, 0xff, /* 0x0e80-0x0e9f */
  0xfc, 0xcc, 0xf0, 0xfc, 0xf7, 0x55, 0x45, 0x0d, /* 0x0ea0-0x0ebf */
  0xff, 0x33, 0x55, 0x05, 0xaa, 0xaa, 0x0a, 0x0f, /* 0x0ec0-0x0edf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x0ee0-0x0eff */
  0x57, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x0f00-0x0f1f */
  0xaa, 0xaa, 0x5a, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x0f20-0x0f3f */
  0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x0f40-0x0f5f */
  0xff, 0xff, 0x3f, 0x00, 0x54, 0x55, 0x55, 0x55, /* 0x0f60-0x0f7f */
  0x55, 0x55, 0xff, 0x00, 0x55, 0x55, 0x54, 0x55, /* 0x0f80-0x0f9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x51, /* 0x0fa0-0x0fbf */
  0x55, 0x55, 0x55, 0x41, 0x00, 0x00, 0x00, 0x00, /* 0x0fc0-0x0fdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x0fe0-0x0fff */
};

static const uintB unicode_attribute_table_page10[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1000-0x101f */
  0xcf, 0xff, 0x3c, 0x55, 0x15, 0x50, 0x05, 0x00, /* 0x1020-0x103f */
  0xaa, 0xaa, 0x5a, 0x55, 0xff, 0x5f, 0x05, 0x00, /* 0x1040-0x105f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1060-0x107f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1080-0x109f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x10a0-0x10bf */
  0xff, 0x0f, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, /* 0x10c0-0x10df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x43, 0x00, /* 0x10e0-0x10ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1100-0x111f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1120-0x113f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xc0, /* 0x1140-0x115f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1160-0x117f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1180-0x119f */
  0x3f, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x11a0-0x11bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x11c0-0x11df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0x00, /* 0x11e0-0x11ff */
  0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1200-0x121f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1220-0x123f */
  0xff, 0x3f, 0xf3, 0x0f, 0xff, 0x3f, 0xf3, 0x0f, /* 0x1240-0x125f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1260-0x127f */
  0xff, 0x3f, 0xf3, 0x0f, 0xff, 0xff, 0xff, 0xff, /* 0x1280-0x129f */
  0xff, 0xff, 0xff, 0x3f, 0xf3, 0x0f, 0xff, 0x3f, /* 0x12a0-0x12bf */
  0xf3, 0x0f, 0xff, 0x3f, 0xff, 0x3f, 0xff, 0xff, /* 0x12c0-0x12df */
  0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, /* 0x12e0-0x12ff */
  0xff, 0xff, 0xff, 0x3f, 0xf3, 0x0f, 0xff, 0x3f, /* 0x1300-0x131f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1320-0x133f */
  0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x00, /* 0x1340-0x135f */
  0x54, 0x55, 0xa9, 0xaa, 0x5a, 0x55, 0x55, 0x01, /* 0x1360-0x137f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1380-0x139f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x13a0-0x13bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x13c0-0x13df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x03, 0x00, 0x00  /* 0x13e0-0x13ff */
};

static const uintB unicode_attribute_table_page14[256] = {
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1400-0x141f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1420-0x143f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1440-0x145f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1460-0x147f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1480-0x149f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x14a0-0x14bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x14c0-0x14df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x14e0-0x14ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1500-0x151f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1520-0x153f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1540-0x155f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1560-0x157f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1580-0x159f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x15a0-0x15bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x15c0-0x15df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x15e0-0x15ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1600-0x161f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1620-0x163f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1640-0x165f */
  0xff, 0xff, 0xff, 0xd7, 0xff, 0x3f, 0x00, 0x00, /* 0x1660-0x167f */
  0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x01, /* 0x1680-0x169f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x16a0-0x16bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x16c0-0x16df */
  0xff, 0xff, 0x7f, 0x55, 0x01, 0x00, 0x00, 0x00, /* 0x16e0-0x16ff */
  0xff, 0xff, 0xff, 0xf3, 0x5f, 0x01, 0x00, 0x00, /* 0x1700-0x171f */
  0xff, 0xff, 0xff, 0xff, 0x5f, 0x15, 0x00, 0x00, /* 0x1720-0x173f */
  0xff, 0xff, 0xff, 0xff, 0x5f, 0x00, 0x00, 0x00, /* 0x1740-0x175f */
  0xff, 0xff, 0xff, 0xf3, 0x53, 0x00, 0x00, 0x00, /* 0x1760-0x177f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1780-0x179f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x55, 0x55, 0x55, /* 0x17a0-0x17bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0xd5, 0x55, 0x03, /* 0x17c0-0x17df */
  0xaa, 0xaa, 0x0a, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x17e0-0x17ff */
};

static const uintB unicode_attribute_table_page18[256] = {
  0x55, 0x55, 0x55, 0x15, 0xaa, 0xaa, 0x0a, 0x00, /* 0x1800-0x181f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1820-0x183f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1840-0x185f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, /* 0x1860-0x187f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1880-0x189f */
  0xff, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x18a0-0x18bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x18c0-0x18df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x18e0-0x18ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1900-0x191f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1920-0x193f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1940-0x195f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1960-0x197f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1980-0x199f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x19a0-0x19bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x19c0-0x19df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x19e0-0x19ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1a00-0x1a1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1a20-0x1a3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1a40-0x1a5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1a60-0x1a7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1a80-0x1a9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1aa0-0x1abf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1ac0-0x1adf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1ae0-0x1aff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1b00-0x1b1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1b20-0x1b3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1b40-0x1b5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1b60-0x1b7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1b80-0x1b9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1ba0-0x1bbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1bc0-0x1bdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x1be0-0x1bff */
};

static const uintB unicode_attribute_table_page1c[256] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1c00-0x1c1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1c20-0x1c3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1c40-0x1c5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1c60-0x1c7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1c80-0x1c9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1ca0-0x1cbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1cc0-0x1cdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1ce0-0x1cff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d00-0x1d1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d20-0x1d3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d40-0x1d5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d60-0x1d7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d80-0x1d9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1da0-0x1dbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1dc0-0x1ddf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1de0-0x1dff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1e00-0x1e1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1e20-0x1e3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1e40-0x1e5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1e60-0x1e7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, /* 0x1e80-0x1e9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1ea0-0x1ebf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1ec0-0x1edf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0x00, /* 0x1ee0-0x1eff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xff, 0x0f, /* 0x1f00-0x1f1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1f20-0x1f3f */
  0xff, 0x0f, 0xff, 0x0f, 0xff, 0xff, 0xcc, 0xcc, /* 0x1f40-0x1f5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, /* 0x1f60-0x1f7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1f80-0x1f9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0x77, /* 0x1fa0-0x1fbf */
  0xf5, 0xf3, 0xff, 0x57, 0xff, 0xf0, 0xff, 0x54, /* 0x1fc0-0x1fdf */
  0xff, 0xff, 0xff, 0x57, 0xf0, 0xf3, 0xff, 0x17  /* 0x1fe0-0x1fff */
};

static const uintB unicode_attribute_table_page20[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2000-0x201f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2020-0x203f */
  0x55, 0x55, 0x55, 0x55, 0x15, 0x40, 0x00, 0x40, /* 0x2040-0x205f */
  0x55, 0x00, 0x50, 0x55, 0x0d, 0x55, 0x55, 0xd5, /* 0x2060-0x207f */
  0x55, 0x55, 0x55, 0x15, 0x00, 0x00, 0x00, 0x00, /* 0x2080-0x209f */
  0x55, 0x55, 0x55, 0x55, 0x05, 0x00, 0x00, 0x00, /* 0x20a0-0x20bf */
  0x00, 0x00, 0x00, 0x00, 0x55, 0x55, 0x55, 0x55, /* 0x20c0-0x20df */
  0x55, 0x55, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x20e0-0x20ff */
  0x75, 0xd5, 0xf5, 0xff, 0xff, 0x5d, 0xfd, 0x5f, /* 0x2100-0x211f */
  0x55, 0x77, 0xf7, 0xdf, 0xdf, 0xff, 0x1f, 0xfc, /* 0x2120-0x213f */
  0x55, 0xfd, 0x5f, 0x00, 0x40, 0x55, 0x55, 0x55, /* 0x2140-0x215f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2160-0x217f */
  0x55, 0x00, 0x00, 0x00, 0x55, 0x55, 0x55, 0x55, /* 0x2180-0x219f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x21a0-0x21bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x21c0-0x21df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x21e0-0x21ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2200-0x221f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2220-0x223f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2240-0x225f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2260-0x227f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2280-0x229f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x22a0-0x22bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x22c0-0x22df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x22e0-0x22ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2300-0x231f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2320-0x233f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2340-0x235f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2360-0x237f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2380-0x239f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x23a0-0x23bf */
  0x55, 0x55, 0x55, 0x15, 0x00, 0x00, 0x00, 0x00, /* 0x23c0-0x23df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x23e0-0x23ff */
};

static const uintB unicode_attribute_table_page24[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2400-0x241f */
  0x55, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2420-0x243f */
  0x55, 0x55, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2440-0x245f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2460-0x247f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2480-0x249f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x24a0-0x24bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x24c0-0x24df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x15, /* 0x24e0-0x24ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2500-0x251f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2520-0x253f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2540-0x255f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2560-0x257f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2580-0x259f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x25a0-0x25bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x25c0-0x25df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x25e0-0x25ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x50, 0x54, 0x55, /* 0x2600-0x261f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2620-0x263f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2640-0x265f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x05, /* 0x2660-0x267f */
  0x55, 0x55, 0x05, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2680-0x269f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x26a0-0x26bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x26c0-0x26df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x26e0-0x26ff */
  0x54, 0x51, 0x05, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2700-0x271f */
  0x55, 0x55, 0x54, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2720-0x273f */
  0x55, 0x55, 0x55, 0x44, 0x15, 0x10, 0x55, 0x15, /* 0x2740-0x275f */
  0x54, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2760-0x277f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x01, 0x55, 0x55, /* 0x2780-0x279f */
  0x55, 0x55, 0x55, 0x55, 0x54, 0x55, 0x55, 0x15, /* 0x27a0-0x27bf */
  0x00, 0x00, 0x00, 0x00, 0x55, 0x55, 0x55, 0x55, /* 0x27c0-0x27df */
  0x55, 0x55, 0x55, 0x00, 0x55, 0x55, 0x55, 0x55  /* 0x27e0-0x27ff */
};

static const uintB unicode_attribute_table_page28[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2800-0x281f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2820-0x283f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2840-0x285f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2860-0x287f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2880-0x289f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x28a0-0x28bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x28c0-0x28df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x28e0-0x28ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2900-0x291f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2920-0x293f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2940-0x295f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2960-0x297f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2980-0x299f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x29a0-0x29bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x29c0-0x29df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x29e0-0x29ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2a00-0x2a1f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2a20-0x2a3f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2a40-0x2a5f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2a60-0x2a7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2a80-0x2a9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2aa0-0x2abf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2ac0-0x2adf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2ae0-0x2aff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2b00-0x2b1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2b20-0x2b3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2b40-0x2b5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2b60-0x2b7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2b80-0x2b9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2ba0-0x2bbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2bc0-0x2bdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x2be0-0x2bff */
};

static const uintB unicode_attribute_table_page2c[256] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2c00-0x2c1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2c20-0x2c3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2c40-0x2c5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2c60-0x2c7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2c80-0x2c9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2ca0-0x2cbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2cc0-0x2cdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2ce0-0x2cff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2d00-0x2d1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2d20-0x2d3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2d40-0x2d5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2d60-0x2d7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2d80-0x2d9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2da0-0x2dbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2dc0-0x2ddf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2de0-0x2dff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2e00-0x2e1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2e20-0x2e3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2e40-0x2e5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2e60-0x2e7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x45, 0x55, /* 0x2e80-0x2e9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2ea0-0x2ebf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2ec0-0x2edf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x00, 0x00, 0x00, /* 0x2ee0-0x2eff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2f00-0x2f1f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2f20-0x2f3f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2f40-0x2f5f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2f60-0x2f7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2f80-0x2f9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x2fa0-0x2fbf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x05, 0x00, 0x00, /* 0x2fc0-0x2fdf */
  0x00, 0x00, 0x00, 0x00, 0x55, 0x55, 0x55, 0x00  /* 0x2fe0-0x2fff */
};

static const uintB unicode_attribute_table_page30[256] = {
  0x55, 0x7d, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3000-0x301f */
  0x55, 0x55, 0x55, 0x55, 0xfd, 0x5f, 0xd5, 0x57, /* 0x3020-0x303f */
  0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3040-0x305f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3060-0x307f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x54, 0xfd, /* 0x3080-0x309f */
  0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x30a0-0x30bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x30c0-0x30df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, /* 0x30e0-0x30ff */
  0x00, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3100-0x311f */
  0xff, 0xff, 0xff, 0x03, 0xfc, 0xff, 0xff, 0xff, /* 0x3120-0x313f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3140-0x315f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3160-0x317f */
  0xff, 0xff, 0xff, 0x3f, 0x55, 0x55, 0x55, 0x55, /* 0x3180-0x319f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, /* 0x31a0-0x31bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x31c0-0x31df */
  0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, /* 0x31e0-0x31ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x01, /* 0x3200-0x321f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3220-0x323f */
  0x55, 0x00, 0x00, 0x00, 0x54, 0x55, 0x55, 0x55, /* 0x3240-0x325f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x40, /* 0x3260-0x327f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3280-0x329f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x32a0-0x32bf */
  0x55, 0x55, 0x55, 0x00, 0x55, 0x55, 0x55, 0x55, /* 0x32c0-0x32df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x15, /* 0x32e0-0x32ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3300-0x331f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3320-0x333f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3340-0x335f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x15, 0x40, 0x55, /* 0x3360-0x337f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x3380-0x339f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x33a0-0x33bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x05, /* 0x33c0-0x33df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x15  /* 0x33e0-0x33ff */
};

static const uintB unicode_attribute_table_page34[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3400-0x341f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3420-0x343f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3440-0x345f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3460-0x347f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3480-0x349f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x34a0-0x34bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x34c0-0x34df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x34e0-0x34ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3500-0x351f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3520-0x353f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3540-0x355f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3560-0x357f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3580-0x359f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x35a0-0x35bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x35c0-0x35df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x35e0-0x35ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3600-0x361f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3620-0x363f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3640-0x365f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3660-0x367f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3680-0x369f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x36a0-0x36bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x36c0-0x36df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x36e0-0x36ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3700-0x371f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3720-0x373f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3740-0x375f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3760-0x377f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x3780-0x379f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x37a0-0x37bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x37c0-0x37df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff  /* 0x37e0-0x37ff */
};

static const uintB unicode_attribute_table_page4c[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4c00-0x4c1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4c20-0x4c3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4c40-0x4c5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4c60-0x4c7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4c80-0x4c9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4ca0-0x4cbf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4cc0-0x4cdf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4ce0-0x4cff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4d00-0x4d1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4d20-0x4d3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4d40-0x4d5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4d60-0x4d7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4d80-0x4d9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, /* 0x4da0-0x4dbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x4dc0-0x4ddf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x4de0-0x4dff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4e00-0x4e1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4e20-0x4e3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4e40-0x4e5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4e60-0x4e7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4e80-0x4e9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4ea0-0x4ebf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4ec0-0x4edf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4ee0-0x4eff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4f00-0x4f1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4f20-0x4f3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4f40-0x4f5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4f60-0x4f7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4f80-0x4f9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4fa0-0x4fbf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x4fc0-0x4fdf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff  /* 0x4fe0-0x4fff */
};

static const uintB unicode_attribute_table_page9c[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9c00-0x9c1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9c20-0x9c3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9c40-0x9c5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9c60-0x9c7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9c80-0x9c9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9ca0-0x9cbf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9cc0-0x9cdf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9ce0-0x9cff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9d00-0x9d1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9d20-0x9d3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9d40-0x9d5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9d60-0x9d7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9d80-0x9d9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9da0-0x9dbf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9dc0-0x9ddf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9de0-0x9dff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9e00-0x9e1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9e20-0x9e3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9e40-0x9e5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9e60-0x9e7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9e80-0x9e9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9ea0-0x9ebf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9ec0-0x9edf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9ee0-0x9eff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9f00-0x9f1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9f20-0x9f3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9f40-0x9f5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9f60-0x9f7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x9f80-0x9f9f */
  0xff, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x9fa0-0x9fbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x9fc0-0x9fdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x9fe0-0x9fff */
};

static const uintB unicode_attribute_table_pagea4[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xa400-0xa41f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xa420-0xa43f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xa440-0xa45f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xa460-0xa47f */
  0xff, 0xff, 0xff, 0x03, 0x55, 0x55, 0x55, 0x55, /* 0xa480-0xa49f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xa4a0-0xa4bf */
  0x55, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa4c0-0xa4df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa4e0-0xa4ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa500-0xa51f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa520-0xa53f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa540-0xa55f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa560-0xa57f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa580-0xa59f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa5a0-0xa5bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa5c0-0xa5df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa5e0-0xa5ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa600-0xa61f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa620-0xa63f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa640-0xa65f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa660-0xa67f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa680-0xa69f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa6a0-0xa6bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa6c0-0xa6df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa6e0-0xa6ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa700-0xa71f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa720-0xa73f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa740-0xa75f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa760-0xa77f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa780-0xa79f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa7a0-0xa7bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa7c0-0xa7df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0xa7e0-0xa7ff */
};

static const uintB unicode_attribute_table_pagea8[256] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa800-0xa81f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa820-0xa83f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa840-0xa85f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa860-0xa87f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa880-0xa89f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa8a0-0xa8bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa8c0-0xa8df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa8e0-0xa8ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa900-0xa91f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa920-0xa93f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa940-0xa95f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa960-0xa97f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa980-0xa99f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa9a0-0xa9bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa9c0-0xa9df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xa9e0-0xa9ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaa00-0xaa1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaa20-0xaa3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaa40-0xaa5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaa60-0xaa7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaa80-0xaa9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaaa0-0xaabf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaac0-0xaadf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaae0-0xaaff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xab00-0xab1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xab20-0xab3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xab40-0xab5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xab60-0xab7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xab80-0xab9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xaba0-0xabbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xabc0-0xabdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0xabe0-0xabff */
};

static const uintB unicode_attribute_table_paged4[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd400-0xd41f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd420-0xd43f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd440-0xd45f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd460-0xd47f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd480-0xd49f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd4a0-0xd4bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd4c0-0xd4df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd4e0-0xd4ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd500-0xd51f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd520-0xd53f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd540-0xd55f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd560-0xd57f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd580-0xd59f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd5a0-0xd5bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd5c0-0xd5df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd5e0-0xd5ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd600-0xd61f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd620-0xd63f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd640-0xd65f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd660-0xd67f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd680-0xd69f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd6a0-0xd6bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd6c0-0xd6df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd6e0-0xd6ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd700-0xd71f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd720-0xd73f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd740-0xd75f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd760-0xd77f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xd780-0xd79f */
  0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xd7a0-0xd7bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xd7c0-0xd7df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0xd7e0-0xd7ff */
};

static const uintB unicode_attribute_table_pagee0[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe000-0xe01f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe020-0xe03f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe040-0xe05f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe060-0xe07f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe080-0xe09f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe0a0-0xe0bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe0c0-0xe0df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe0e0-0xe0ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe100-0xe11f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe120-0xe13f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe140-0xe15f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe160-0xe17f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe180-0xe19f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe1a0-0xe1bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe1c0-0xe1df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe1e0-0xe1ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe200-0xe21f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe220-0xe23f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe240-0xe25f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe260-0xe27f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe280-0xe29f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe2a0-0xe2bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe2c0-0xe2df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe2e0-0xe2ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe300-0xe31f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe320-0xe33f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe340-0xe35f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe360-0xe37f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe380-0xe39f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe3a0-0xe3bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe3c0-0xe3df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55  /* 0xe3e0-0xe3ff */
};

static const uintB unicode_attribute_table_pagef8[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf800-0xf81f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf820-0xf83f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf840-0xf85f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf860-0xf87f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf880-0xf89f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf8a0-0xf8bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf8c0-0xf8df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xf8e0-0xf8ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf900-0xf91f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf920-0xf93f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf940-0xf95f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf960-0xf97f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf980-0xf99f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf9a0-0xf9bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf9c0-0xf9df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xf9e0-0xf9ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfa00-0xfa1f */
  0xff, 0xff, 0xff, 0x0f, 0xff, 0xff, 0xff, 0xff, /* 0xfa20-0xfa3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfa40-0xfa5f */
  0xff, 0xff, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xfa60-0xfa7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xfa80-0xfa9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xfaa0-0xfabf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xfac0-0xfadf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xfae0-0xfaff */
  0xff, 0x3f, 0x00, 0x00, 0xc0, 0xff, 0x00, 0xdc, /* 0xfb00-0xfb1f */
  0xff, 0xff, 0xf7, 0xff, 0xff, 0x3f, 0xff, 0x33, /* 0xfb20-0xfb3f */
  0xcf, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfb40-0xfb5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfb60-0xfb7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfb80-0xfb9f */
  0xff, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0x00, /* 0xfba0-0xfbbf */
  0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0xff, 0xff, /* 0xfbc0-0xfbdf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff  /* 0xfbe0-0xfbff */
};

static const uintB unicode_attribute_table_pagefc[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfc00-0xfc1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfc20-0xfc3f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfc40-0xfc5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfc60-0xfc7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfc80-0xfc9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfca0-0xfcbf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfcc0-0xfcdf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfce0-0xfcff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfd00-0xfd1f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, /* 0xfd20-0xfd3f */
  0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, /* 0xfd40-0xfd5f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfd60-0xfd7f */
  0xff, 0xff, 0xff, 0xff, 0xf0, 0xff, 0xff, 0xff, /* 0xfd80-0xfd9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfda0-0xfdbf */
  0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xfdc0-0xfddf */
  0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x01, /* 0xfde0-0xfdff */
  0x55, 0x55, 0x55, 0x55, 0x00, 0x00, 0x00, 0x00, /* 0xfe00-0xfe1f */
  0x55, 0x00, 0x00, 0x00, 0x55, 0x55, 0x55, 0x55, /* 0xfe20-0xfe3f */
  0x55, 0x15, 0x54, 0x55, 0x15, 0x55, 0x55, 0x55, /* 0xfe40-0xfe5f */
  0x55, 0x15, 0x55, 0x00, 0xff, 0xf3, 0xff, 0xff, /* 0xfe60-0xfe7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfe80-0xfe9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfea0-0xfebf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xfec0-0xfedf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x43, /* 0xfee0-0xfeff */
  0x54, 0x55, 0x55, 0x55, 0xaa, 0xaa, 0x5a, 0x55, /* 0xff00-0xff1f */
  0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x55, /* 0xff20-0xff3f */
  0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x55, /* 0xff40-0xff5f */
  0x55, 0xf5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xff60-0xff7f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0xff80-0xff9f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, /* 0xffa0-0xffbf */
  0xf0, 0xff, 0xf0, 0xff, 0xf0, 0xff, 0xf0, 0x03, /* 0xffc0-0xffdf */
  0x55, 0x15, 0x55, 0x15, 0x00, 0x00, 0x54, 0x05  /* 0xffe0-0xffff */
};

static const uintB unicode_attribute_table_page100[256] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10000-0x1001f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10020-0x1003f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10040-0x1005f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10060-0x1007f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10080-0x1009f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x100a0-0x100bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x100c0-0x100df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x100e0-0x100ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10100-0x1011f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10120-0x1013f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10140-0x1015f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10160-0x1017f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10180-0x1019f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x101a0-0x101bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x101c0-0x101df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x101e0-0x101ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10200-0x1021f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10220-0x1023f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10240-0x1025f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10260-0x1027f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10280-0x1029f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x102a0-0x102bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x102c0-0x102df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x102e0-0x102ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, /* 0x10300-0x1031f */
  0x55, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, /* 0x10320-0x1033f */
  0xff, 0xff, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10340-0x1035f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10360-0x1037f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10380-0x1039f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x103a0-0x103bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x103c0-0x103df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x103e0-0x103ff */
};

static const uintB unicode_attribute_table_page104[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x10400-0x1041f */
  0xff, 0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x10420-0x1043f */
  0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0x00, 0x00, /* 0x10440-0x1045f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10460-0x1047f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10480-0x1049f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x104a0-0x104bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x104c0-0x104df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x104e0-0x104ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10500-0x1051f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10520-0x1053f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10540-0x1055f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10560-0x1057f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10580-0x1059f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x105a0-0x105bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x105c0-0x105df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x105e0-0x105ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10600-0x1061f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10620-0x1063f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10640-0x1065f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10660-0x1067f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10680-0x1069f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x106a0-0x106bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x106c0-0x106df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x106e0-0x106ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10700-0x1071f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10720-0x1073f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10740-0x1075f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10760-0x1077f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x10780-0x1079f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x107a0-0x107bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x107c0-0x107df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x107e0-0x107ff */
};

static const uintB unicode_attribute_table_page1d0[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d000-0x1d01f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d020-0x1d03f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d040-0x1d05f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d060-0x1d07f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d080-0x1d09f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d0a0-0x1d0bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d0c0-0x1d0df */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x05, 0x00, 0x00, /* 0x1d0e0-0x1d0ff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d100-0x1d11f */
  0x55, 0x15, 0x50, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d120-0x1d13f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d140-0x1d15f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d160-0x1d17f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d180-0x1d19f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0x1d1a0-0x1d1bf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x05, /* 0x1d1c0-0x1d1df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d1e0-0x1d1ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d200-0x1d21f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d220-0x1d23f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d240-0x1d25f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d260-0x1d27f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d280-0x1d29f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d2a0-0x1d2bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d2c0-0x1d2df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d2e0-0x1d2ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d300-0x1d31f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d320-0x1d33f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d340-0x1d35f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d360-0x1d37f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d380-0x1d39f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d3a0-0x1d3bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x1d3c0-0x1d3df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x1d3e0-0x1d3ff */
};

static const uintB unicode_attribute_table_page1d4[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d400-0x1d41f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d420-0x1d43f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, /* 0x1d440-0x1d45f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d460-0x1d47f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, /* 0x1d480-0x1d49f */
  0x30, 0x3c, 0xfc, 0xf3, 0xff, 0xff, 0xcf, 0xfc, /* 0x1d4a0-0x1d4bf */
  0xf3, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d4c0-0x1d4df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d4e0-0x1d4ff */
  0xff, 0xcf, 0x3f, 0xfc, 0xff, 0xf3, 0xff, 0xf3, /* 0x1d500-0x1d51f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcf, 0x3f, /* 0x1d520-0x1d53f */
  0xff, 0x33, 0xf0, 0xff, 0xf3, 0xff, 0xff, 0xff, /* 0x1d540-0x1d55f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d560-0x1d57f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d580-0x1d59f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d5a0-0x1d5bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d5c0-0x1d5df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d5e0-0x1d5ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d600-0x1d61f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d620-0x1d63f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d640-0x1d65f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d660-0x1d67f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d680-0x1d69f */
  0xff, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d6a0-0x1d6bf */
  0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, /* 0x1d6c0-0x1d6df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, /* 0x1d6e0-0x1d6ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, /* 0x1d700-0x1d71f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, /* 0x1d720-0x1d73f */
  0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, /* 0x1d740-0x1d75f */
  0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, /* 0x1d760-0x1d77f */
  0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d780-0x1d79f */
  0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x1d7a0-0x1d7bf */
  0x7f, 0xff, 0x0f, 0xa0, 0xaa, 0xaa, 0xaa, 0xaa, /* 0x1d7c0-0x1d7df */
  0xaa, 0xaa, 0xaa, 0xaa, 0xaa, 0xaa, 0xaa, 0xaa  /* 0x1d7e0-0x1d7ff */
};

static const uintB unicode_attribute_table_page2a4[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a400-0x2a41f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a420-0x2a43f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a440-0x2a45f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a460-0x2a47f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a480-0x2a49f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a4a0-0x2a4bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a4c0-0x2a4df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a4e0-0x2a4ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a500-0x2a51f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a520-0x2a53f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a540-0x2a55f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a560-0x2a57f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a580-0x2a59f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a5a0-0x2a5bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a5c0-0x2a5df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a5e0-0x2a5ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a600-0x2a61f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a620-0x2a63f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a640-0x2a65f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a660-0x2a67f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a680-0x2a69f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2a6a0-0x2a6bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x00, 0x00, /* 0x2a6c0-0x2a6df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a6e0-0x2a6ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a700-0x2a71f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a720-0x2a73f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a740-0x2a75f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a760-0x2a77f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a780-0x2a79f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a7a0-0x2a7bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2a7c0-0x2a7df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x2a7e0-0x2a7ff */
};

static const uintB unicode_attribute_table_page2f8[256] = {
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f800-0x2f81f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f820-0x2f83f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f840-0x2f85f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f860-0x2f87f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f880-0x2f89f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f8a0-0x2f8bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f8c0-0x2f8df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f8e0-0x2f8ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f900-0x2f91f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f920-0x2f93f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f940-0x2f95f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f960-0x2f97f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f980-0x2f99f */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f9a0-0x2f9bf */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f9c0-0x2f9df */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, /* 0x2f9e0-0x2f9ff */
  0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x0f, /* 0x2fa00-0x2fa1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fa20-0x2fa3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fa40-0x2fa5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fa60-0x2fa7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fa80-0x2fa9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2faa0-0x2fabf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fac0-0x2fadf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fae0-0x2faff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fb00-0x2fb1f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fb20-0x2fb3f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fb40-0x2fb5f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fb60-0x2fb7f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fb80-0x2fb9f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fba0-0x2fbbf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0x2fbc0-0x2fbdf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0x2fbe0-0x2fbff */
};

static const uintB unicode_attribute_table_pagee00[256] = {
  0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0000-0xe001f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe0020-0xe003f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe0040-0xe005f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xe0060-0xe007f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0080-0xe009f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe00a0-0xe00bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe00c0-0xe00df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe00e0-0xe00ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0100-0xe011f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0120-0xe013f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0140-0xe015f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0160-0xe017f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0180-0xe019f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe01a0-0xe01bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe01c0-0xe01df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe01e0-0xe01ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0200-0xe021f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0220-0xe023f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0240-0xe025f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0260-0xe027f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0280-0xe029f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe02a0-0xe02bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe02c0-0xe02df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe02e0-0xe02ff */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0300-0xe031f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0320-0xe033f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0340-0xe035f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0360-0xe037f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe0380-0xe039f */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe03a0-0xe03bf */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* 0xe03c0-0xe03df */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  /* 0xe03e0-0xe03ff */
};

static const uintB unicode_attribute_table_pageffc[256] = {
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffc00-0xffc1f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffc20-0xffc3f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffc40-0xffc5f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffc60-0xffc7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffc80-0xffc9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffca0-0xffcbf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffcc0-0xffcdf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffce0-0xffcff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffd00-0xffd1f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffd20-0xffd3f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffd40-0xffd5f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffd60-0xffd7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffd80-0xffd9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffda0-0xffdbf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffdc0-0xffddf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffde0-0xffdff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffe00-0xffe1f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffe20-0xffe3f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffe40-0xffe5f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffe60-0xffe7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffe80-0xffe9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffea0-0xffebf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffec0-0xffedf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xffee0-0xffeff */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfff00-0xfff1f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfff20-0xfff3f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfff40-0xfff5f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfff60-0xfff7f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfff80-0xfff9f */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfffa0-0xfffbf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, /* 0xfffc0-0xfffdf */
  0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x05  /* 0xfffe0-0xfffff */
};

const uintB * const unicode_attribute_table[1088] = {
  unicode_attribute_table_page00, unicode_attribute_table_page04,
  unicode_attribute_table_page08, unicode_attribute_table_page0c,
  unicode_attribute_table_page10, unicode_attribute_table_page14,
  unicode_attribute_table_page18, unicode_attribute_table_page1c,
  unicode_attribute_table_page20, unicode_attribute_table_page24,
  unicode_attribute_table_page28, unicode_attribute_table_page2c,
  unicode_attribute_table_page30, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page4c,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page9c,
  unicode_attribute_table_page34, unicode_attribute_table_pagea4,
  unicode_attribute_table_pagea8, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_paged4,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagef8, unicode_attribute_table_pagefc,
  unicode_attribute_table_page100, unicode_attribute_table_page104,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_page1d0, unicode_attribute_table_page1d4,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page34,
  unicode_attribute_table_page34, unicode_attribute_table_page2a4,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_page2f8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagee00, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagea8, unicode_attribute_table_pagea8,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pageffc,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pagee0,
  unicode_attribute_table_pagee0, unicode_attribute_table_pageffc
};

